@@ -1,4 +1,5 @@
 'use strict';
+
 var assert = require('simple-assert');
 var eql = require('..');
 var MemoizeMap = require('..').MemoizeMap;
@@ -54,9 +55,9 @@ describe('Generic', function () {
 
     it('returns false for instances with different values', function () {
       assert(eql(new Boolean(false), new Boolean(true)) === false,
-      'eql(new Boolean(false), new Boolean(true)) === false');
+        'eql(new Boolean(false), new Boolean(true)) === false');
       assert(eql(new Boolean(true), new Boolean(false)) === false,
-      'eql(new Boolean(true), new Boolean(false)) === false');
+        'eql(new Boolean(true), new Boolean(false)) === false');
     });
 
     it('returns false for different values', function () {
@@ -376,6 +377,48 @@ describe('Generic', function () {
 
   });
 
+  describe('Symbols', function () {
+
+    it('returns true for same symbols', function () {
+      var symb = Symbol('a');
+      var objectA = { [symb]: 'a' };
+      var objectB = { [symb]: 'a' };
+      assert(eql(objectA, objectB) === true, 'eql(obj, obj)');
+    });
+
+    it('returns false for different values', function () {
+      var symb = Symbol('a');
+      var objectA = { [symb]: 'a' };
+      var objectB = { [symb]: 'b' };
+      assert(eql(objectA, objectB) === false, 'eql(obj, obj) === false');
+    });
+
+    it('returns false for different symbols', function () {
+      var symb = Symbol('a');
+      var symb2 = Symbol('b');
+      var objectA = { [symb]: 'a' };
+      var objectB = { [symb2]: 'a' };
+      assert(eql(objectA, objectB) === false, 'eql(obj, obj) === false');
+    });
+
+    it('returns true for same nested symbols', function () {
+      var symb = Symbol('a');
+      var symb2 = Symbol('b');
+      var objectA = { [symb]: { [symb2]: 'a' } };
+      var objectB = { [symb]: { [symb2]: 'a' } };
+      assert(eql(objectA, objectB) === true, 'eql(obj, obj)');
+    });
+
+    it('returns false for different nested symbols', function () {
+      var symb = Symbol('a');
+      var symb2 = Symbol('b');
+      var objectA = { [symb]: { [symb2]: 'a' } };
+      var objectB = { [symb]: { [symb]: 'a' } };
+      assert(eql(objectA, objectB) === false, 'eql(obj, obj) === false');
+    });
+  });
+
+
   describe('errors', function () {
 
     it('returns true for same errors', function () {
@@ -450,12 +493,12 @@ describe('Node Specific', function () {
   describeIf(typeof Buffer === 'function')('buffers', function () {
 
     it('returns true for same buffers', function () {
-      assert(eql(new Buffer([ 1 ]), new Buffer([ 1 ])) === true,
+      assert(eql(Buffer.from([ 1 ]), Buffer.from([ 1 ])) === true,
         'eql(new Buffer([ 1 ]), new Buffer([ 1 ])) === true');
     });
 
     it('returns false for different buffers', function () {
-      assert(eql(new Buffer([ 1 ]), new Buffer([ 2 ])) === false,
+      assert(eql(Buffer.from([ 1 ]), Buffer.from([ 2 ])) === false,
         'eql(new Buffer([ 1 ]), new Buffer([ 2 ])) === false');
     });
 
